@@ -2,7 +2,7 @@ import binascii
 
 import pytest
 import regex as re
-from multidecoder.decoders.base64 import BASE64_RE, find_base64, find_FromBase64String, pad_base64
+from multidecoder.decoders.base64 import BASE64_RE, find_atob, find_base64, find_FromBase64String, pad_base64
 from multidecoder.node import Node
 
 # -- pad_base64 --
@@ -21,6 +21,19 @@ def test_pad_base64(base64, padded):
     assert pad_base64(base64) == padded
 
 
+# -- find_atob --
+
+
+@pytest.mark.parametrize(
+    ("atob", "decoded"),
+    [
+        (b"atob('YXRvYiB0ZXN0IHRleHQ=')", b"atob test text"),
+    ],
+)
+def test_atob(atob, decoded):
+    assert find_atob(atob)[0].value == decoded
+
+
 # -- find_base64 --
 
 
